﻿//DESCRIPTION: Script to automate cover template creation based on user input for page count and trim.
// Cover Template.jsx
//
// Modified 2020-09-2
// Julie Taylor, Michigan State University Libraries
// lib.msu.edu/publish


// User Interface Dialogue Box
// Accepts Page Count, Trim Width, Trim Height
    var myDialog = app.dialogs.add({name:"Cover Template Options",canCancel:true});
    with(myDialog){
    // Add dialog columns:
    // First column contains labels
    // Second column contains values
    with(dialogColumns.add()){
    staticTexts.add({staticLabel:"Page Count:"});
    staticTexts.add({staticLabel:"Trim Width:"});
    staticTexts.add({staticLabel:"Trim Height:"});
    staticTexts.add({staticLabel:"Cover Stock:"});
    var myCoverStockList = ["Matte","Satin","Gloss"];
    
    }
    with(dialogColumns.add()){
    // Create an integer edit field for page count
    var myPageCountField = integerEditboxes.add({editValue:40, minimumValue:10, maximumValue:800});
    // Create real number entries field for trim sizes
    var myTrimWidthField = realEditboxes.add({editValue:6, minimumValue:2.5, maximumValue:8.375});
    var myTrimHeightField = realEditboxes.add({editValue:9,minimumValue:2.5, maximumValue:10.75});
    // Create a dropdown list for cover stock entry
    var myCoverStock = dropdowns.add({stringList:myCoverStockList, selectedIndex:0});    
    }
    }
    //Display the dialog box.
    var myResult = myDialog.show();
    if(myResult == true){
    //Get the values from the dialog box controls.
    var myPageCount = myPageCountField.editValue; 
    var myTrimWidth = myTrimWidthField.editValue;
    var myTrimHeight = myTrimHeightField.editValue;
    var myStock = myCoverStockList [myCoverStock.selectedIndex];
    //alert (myCoverStockList [myCoverStock.selectedIndex]);
    //Remove the dialog box from memory.
    myDialog.destroy();
    myMakeDocument(myPageCount, myTrimWidth,myTrimHeight);
    }    
    else{
    myDialog.destroy();
    }

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function to create page
// set document 
// set preferences
// set document margins
// set pasteboard margins
// add spine fold marks (to help align binding)
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// 
 function myMakeDocument() {
      var myPPI = 440; 
      var myColumnGutter = myPageCount / myPPI;
    
//  Determine whether document page size should be 17" wide or 19" wide
//  if the front cover, back cover, spine, and crop marks are larger than 17, set the document width to 19
    var myTestDocSize = myTrimWidth * 2 + myColumnGutter + 1;

    if(myTestDocSize > 17){
    mypageWidth = 19;
    myZero = "9.5in";
    }
    else{
    mypageWidth = 17;
    myZero = "8.5in";
    }    

      var myMarginVertical = (11 - myTrimHeight) / 2;
      var myMarginHorizontal = (mypageWidth - (myTrimWidth * 2 + myColumnGutter)) /2;

    // Create a new INDD document
    // Use the documentPreferences object to change the dimensions and orientation of the document.
    var myDoc = app.documents.add();
    with(myDoc.documentPreferences){
        pageHeight = "11in";
        pageWidth = mypageWidth + "in";
        pageOrientation = PageOrientation.landscape;
        pagesPerDocument = 1;
        facingPages = false;
    }
    with(myDoc.viewPreferences){
       //Measurement unit choices are:
       //* MeasurementUnits.picas
       //* MeasurementUnits.points
       //* MeasurementUnits.inches
       //* MeasurementUnits.inchesDecimal
       //* MeasurementUnits.millimeters
       //* MeasurementUnits.centimeters
       //* MeasurementUnits.ciceros
       //Set horizontal and vertical measurement units to points.
       horizontalMeasurementUnits = MeasurementUnits.inches;
       verticalMeasurementUnits = MeasurementUnits.inches;
    }
    with (myDoc.pages.item(0).marginPreferences){
       columnCount = 2;
       //columnGutter can be a number or a measurement string.
       columnGutter = myColumnGutter;
        // When document.documentPreferences.facingPages == true, 
       // "left" means inside; "right" means outside.
       bottom = myMarginVertical;
       left = myMarginHorizontal;
       right = myMarginHorizontal;
       top = myMarginVertical;
    }
    // use the pasteboardPreferences object to change the dimensions of the pastboard margin
    // then zoom out to the pastboard view
    myDoc.pasteboardPreferences.pasteboardMargins = ["4in","2in"];
    app.activeWindow.zoom(ZoomOptions.SHOW_PASTEBOARD);
    // set document preferences
	myDoc.viewPreferences.showRulers = true;
	myDoc.viewPreferences.showFrameEdges = true;
	myDoc.guidePreferences.guidesShown = true;
	myDoc.guidePreferences.guidesLocked = false;
	myDoc.guidePreferences.guidesSnapto = true; 
    myDoc.viewPreferences.rulerOrigin = RulerOrigin.PAGE_ORIGIN; // SPREAD_ORIGIN, PAGE_ORIGIN, SPINE_ORIGIN
    myDoc.zeroPoint = [myZero,"5.5in"];


/////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Section to add spine fold line marks near the page edges
// and add crop marks
//
////////////////////////////////////////////////////////////////////////////////////////////////////////

var myLine = [];  
var mySpine = (myPageCount / 435) /2;     // width of spine divided in half  (x position)
var myLineStart = 5.325                              // line start position (y position 1)
var myLineEnd = 5.5                                   // line end position (y position 2)
var myCropX = myTrimWidth + myColumnGutter/2;                   // X position for vertical crop marks
var myCropX1 = myTrimWidth + myColumnGutter/2 + 0.125;    // X start position with offset for horizontal crop marks
var myCropX2 = myCropX1 + 0.25;                                           // X end position with offset for horizontal crop marks
var myCropY = myTrimHeight/2;                                              // Y posiiton for horizontal crop marks
var myCropY1 = myTrimHeight/2 + 0.125;                               // Y start position with offset for vertical crop marks
var myCropY2 = myCropY1 + 0.25;                                          // Y end position with offset for vertical crop marks
  
// create a 50% black swatch
myGray = myDoc.colors.add({name:"Gray 50%", model:ColorModel.process, colorValue:[0, 0, 0, 50]});    
  
for (var j = 1; j <= 12; j++) {  
        myLine[j] = app.activeDocument.graphicLines.add();  
        myLine[j].strokeColor = myGray;
        myLine[j].strokeWeight = 0.75;  
        }  
   
plotStraightLine(myLine[1], -mySpine,myLineStart,-mySpine,myLineEnd);  
plotStraightLine(myLine[2], -mySpine,-myLineStart,-mySpine,-myLineEnd);  
plotStraightLine(myLine[3], mySpine,myLineStart,mySpine,myLineEnd);    
plotStraightLine(myLine[4], mySpine,-myLineStart,mySpine,-myLineEnd);  
plotStraightLine(myLine[5], myCropX,-myCropY1,myCropX,-myCropY2);
plotStraightLine(myLine[6], myCropX1,-myCropY,myCropX2,-myCropY);
plotStraightLine(myLine[7], myCropX1,myCropY,myCropX2,myCropY);
plotStraightLine(myLine[8], myCropX,myCropY1,myCropX,myCropY2);
plotStraightLine(myLine[9], -myCropX1,myCropY,-myCropX2,myCropY);
plotStraightLine(myLine[10], -myCropX,myCropY1,-myCropX,myCropY2);
plotStraightLine(myLine[11], -myCropX,-myCropY1,-myCropX,-myCropY2);
plotStraightLine(myLine[12], -myCropX1,-myCropY,-myCropX2,-myCropY);
  
function plotStraightLine(obj, x1, y1, x2, y2) {  
    obj.paths.item(0).pathPoints.item(0).anchor = [x1, y1];  
    obj.paths.item(0).pathPoints.item(1).anchor = [x2, y2];  
    }  

////////////////////////////////////////////////////////////////////////////////////////////////////////////////// 
    //  Add text frame to identify trim cuts:    
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////    
    var myPage = app.activeWindow.activePage;
    var myTrimText = myDoc.pages.item(0).textFrames.add(
{geometricBounds:[ myLineStart,mySpine,myLineEnd,myTrimWidth], contents:"Trim Values    >    Cut 1 (width): " + myTrimWidth + " inches    Cut 2 (top): " + (((11 - myTrimHeight)/2)+myTrimHeight) + " inches    Cut 3 (bottom): " + myTrimHeight + " inches"});

    // set size, justification, color to trim text
    var myText1 = myTrimText.parentStory.paragraphs.item(0)
    myText1.pointSize = 6;
    myText1.justification = Justification.centerAlign;
    myText1.fillColor = myGray;
    myText1.appliedFont = app.fonts.item("Myriad Pro");
    myText1.fontStyle = "Light";
    
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////// 
    //  Add text frame to identify cover stock  
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////    
    var myPage = app.activeWindow.activePage;
    var myTrimText = myDoc.pages.item(0).textFrames.add(
{geometricBounds:[ myLineStart,-mySpine,myLineEnd,-myTrimWidth], contents:"Cover Stock: " + myStock});

    // set size, justification, color to trim text
    var myText1 = myTrimText.parentStory.paragraphs.item(0)
    myText1.pointSize = 6;
    myText1.justification = Justification.centerAlign;
    myText1.fillColor = myGray;
    myText1.appliedFont = app.fonts.item("Myriad Pro");
    myText1.fontStyle = "Light";
 
 
 }